package com.example.demo.controllers;

import java.util.List;

import com.example.demo.config.Constants;
import com.example.demo.dtos.GameDto;
import com.example.demo.dtos.PlayDto;
import com.example.demo.services.GameService;
import com.example.demo.services.PlayService;
import com.example.demo.services.CustomerService;
import com.example.demo.dtos.CustomerDto;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping(Constants.API_URL + "/customers")
public class CustomerController {
    private final CustomerService customerService;

    private final GameService gameService;

    public CustomerController(CustomerService customerService, GameService gameService, PlayService playService){
        this.customerService = customerService;
        this.gameService = gameService;
    }

    @GetMapping
    public List<CustomerDto> getAll()
    {
        return customerService.getAllCustomers().stream().map(CustomerDto::new).toList();
    }

    @GetMapping("/{id}")
    public CustomerDto get(@PathVariable(name = "id") long id) {
        return new CustomerDto(customerService.findCustomer(id));
    }

    @PostMapping
    public CustomerDto create(@RequestBody CustomerDto customer) {
        return new CustomerDto(customerService.addCustomer(customer.getName()));
    }

    @PutMapping("/{id}")
    public CustomerDto update(
            @PathVariable(name = "id") long id,
            @RequestBody CustomerDto customer) {
        return new CustomerDto(customerService.updateCustomer(id, customer.getName()));
    }

    @DeleteMapping("/{id}")
    public CustomerDto delete(@PathVariable(name = "id") long id) {
        return new CustomerDto(customerService.deleteCustomer(id));
    }

    @PostMapping("/{id}/games")
    public GameDto createGame(@PathVariable(name = "id") long id, @RequestBody GameDto game){
        return new GameDto(gameService.addGame(id, game.getName(), game.getDescription()));
    }
}
