package com.example.demo.controllers;

import com.example.demo.config.Constants;
import com.example.demo.dtos.GameDto;
import com.example.demo.dtos.PlayDto;
import com.example.demo.services.GameService;
import com.example.demo.services.PlayService;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping(Constants.API_URL + "/games")
public class GameController {
    private final GameService gameService;

    private final PlayService playService;

    public GameController(GameService gameService, PlayService playService){
        this.gameService = gameService;
        this.playService = playService;
    }

    @GetMapping
    public List<GameDto> getAll() {
        return gameService.getAllGames().stream().map(GameDto::new).toList();
    }

    @GetMapping("/{id}")
    public GameDto get(@PathVariable(name = "id") long id) {
        return new GameDto(gameService.findGame(id));
    }

    @PutMapping("/{id}")
    public GameDto update(@PathVariable(name = "id") long id, @RequestBody GameDto game) {
        return new GameDto(gameService.updateGame(id, game.getName(), game.getDescription()));
    }

    @DeleteMapping("/{id}")
    public GameDto delete(@PathVariable(name = "id") long id)
    {
        return new GameDto(gameService.deleteGame(id));
    }

    @PostMapping("/{id}/plays")
    public PlayDto create(@PathVariable(name = "id") long id, @RequestBody PlayDto play) {
        return new  PlayDto(playService.addPlay(id, play.getDate(), play.getDescription()));
    }
}