package com.example.demo.controllers;

import com.example.demo.config.Constants;
import com.example.demo.dtos.CustomerDto;
import com.example.demo.dtos.PlayDto;
import com.example.demo.services.PlayService;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping(Constants.API_URL + "/plays")
public class PlayController {
    private final PlayService playService;

    public PlayController(PlayService playService){

        this.playService = playService;
    }

    @GetMapping
    public List<PlayDto> getAll()
    {
        return playService.getAllPlays().stream().map(PlayDto::new).toList();
    }

    @GetMapping("/{id}")
    public PlayDto get(@PathVariable(name = "id") long id)
    {
        return new PlayDto(playService.findPlay(id));
    }

    @PutMapping("/{id}")
    public PlayDto update(@PathVariable(name = "id") long id, @RequestBody PlayDto play) {
        return new PlayDto(playService.updatePlay(id, play.getDate(), play.getDescription()));
    }

    @DeleteMapping("/{id}")
    public PlayDto delete(@PathVariable(name = "id") long id)
    {
        return new PlayDto(playService.deletePlay(id));
    }

    @PostMapping("/{id}/customers")
    public boolean addCustomer(@PathVariable(name = "id") long id, @RequestParam long customerId){
        return playService.addCustomer(id, customerId);
    }
}
