package com.example.demo.models;

import jakarta.persistence.*;

import java.util.*;

@Entity
public class Game {
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private long id;

    private long customerId;

    @Column(length = 50)
    private String name;

    @Column(length = 500)
    private String description;

    @ManyToOne
    @JoinColumn(name = "customerId", updatable = false, insertable = false)
    private Customer customer;

    @OneToMany(mappedBy = "game", cascade = CascadeType.ALL, orphanRemoval = true)
    @OrderBy("date desc")
    Set<Play> plays = new HashSet<>();

    public Game() {
    }

    public Game(String name, String description, Customer customer) {
        this.name = name;
        this.customer = customer;
        this.customerId = customer.getId();
        this.description = description;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Game game = (Game) o;
        return Objects.equals(customerId, game.customerId) && Objects.equals(name, game.name);
    }

    @Override
    public int hashCode() {
        return Objects.hash(customerId, name);
    }

    public long getId() {
        return id;
    }

    public String getName(){
        return name;
    }
    public void setName(String name){
        this.name = name;
    }

    public String getDescription(){
        return description;
    }
    public void setDescription(String description){
        this.description = description;
    }

    public Customer getCustomer(){
        return customer;
    }
    public void setCustomer(Customer customer){
        this.customer = customer;
        this.customerId = customer.getId();
    }

    public long getCustomerId(){
        return customerId;
    }

    public Set<Play> getPlays(){
        return plays;
    }
    public void setPlays(Set<Play> plays){
        this.plays = plays;
    }
}
