package com.example.demo.models;

import jakarta.persistence.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;

@Entity
public class Play {
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private long id;

    private long gameId;

    @Column(length = 500)
    private String description;

    @Column(nullable = false)
    private Date date;

    @ManyToOne()
    @JoinColumn(name = "gameId", updatable = false, insertable = false)
    private Game game;

    @ManyToMany
    @JoinTable(name="plays_customers",
            joinColumns = @JoinColumn(name="playId", referencedColumnName="id"),
            inverseJoinColumns= @JoinColumn(name="customerId", referencedColumnName="id") )
    @OrderBy("name asc")
    private List<Customer> customers = new ArrayList<>();

    public Play() {

    }

    public Play(Game game, Date date, String description){
        this.description = description;
        this.date = date;
        this.game = game;
        this.gameId = game.getId();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Play cart = (Play) o;
        return Objects.equals(gameId, cart.gameId) && Objects.equals(date, cart.date);
    }

    @Override
    public int hashCode() {
        return Objects.hash(gameId, date);
    }

    public long getId() {
        return id;
    }

    public String getDescription(){
        return description;
    }
    public void setDescription(String description){
        this.description = description;
    }

    public Date getDate(){
        return date;
    }
    public void setDate(Date date){
        this.date = date;
    }

    public Game getGame(){
        return game;
    }
    public void setGame(Game game){
        this.game = game;
        this.gameId = game.getId();
    }

    public Long getGameId(){
        return gameId;
    }

    public List<Customer> getCustomers(){
        return customers;
    }
    public void setCustomers(List<Customer> customers){
        this.customers = customers;
    }
    public boolean addCustomer(Customer customer){
        return customers.add(customer);
    }
}
