package com.example.demo.services;

import com.example.demo.errors.NotFoundException;
import com.example.demo.models.Customer;
import com.example.demo.repositories.CustomerRepository;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
public class CustomerService {
    private final CustomerRepository repository;

    public CustomerService(CustomerRepository repository){
        this.repository = repository;
    }

    @Transactional
    public Customer addCustomer(String name) {
        Customer customer = new Customer(name);
        return repository.save(customer);
    }

    @Transactional
    public Customer findCustomer(Long id){
        var customer = repository.findByIdWidthPlays(id);
        return customer != null ?
                repository.findByIdWidthGames(id).orElseThrow(() -> new NotFoundException(Customer.class, id)) :
                customer.orElseThrow(() -> new NotFoundException(Customer.class, id));
    }

    @Transactional
    public List<Customer> getAllCustomers(){
        var customers = repository.findAllWidthGames();
        return !customers.isEmpty() ? repository.findAllWidthPlays() : customers;
    }

    @Transactional
    public Customer updateCustomer(Long id, String name){
        Customer customer = findCustomer(id);
        customer.setName(name);

        return repository.save(customer);
    }

    @Transactional
    public Customer deleteCustomer(Long id){
        Customer customer = findCustomer(id);
        repository.delete(customer);
        return customer;
    }
}
