package com.example.demo.services;

import com.example.demo.errors.NotFoundException;
import com.example.demo.models.Customer;
import com.example.demo.models.Game;
import com.example.demo.repositories.GameRepository;
import jakarta.persistence.EntityManager;
import jakarta.persistence.PersistenceContext;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
public class GameService {
    private final GameRepository repository;

    private final CustomerService customerService;
    
    public GameService(GameRepository repository, CustomerService customerService){
        this.repository = repository;
        this.customerService = customerService;
    }

    @Transactional
    public Game addGame(Long customerId, String name, String description){
        Customer customer = customerService.findCustomer(customerId);
        Game game = new Game(name, description, customer);
        return repository.save(game);
    }

    @Transactional
    public Game findGame(Long id){
        return repository.findById(id).orElseThrow(
                () -> new NotFoundException(Game.class, id));
    }

    @Transactional
    public List<Game> getAllGames(){
        return repository.findAll();
    }

    @Transactional
    public Game updateGame(Long id, String name, String description){
        Game game = findGame(id);
        game.setName(name);
        game.setDescription(description);

        return repository.save(game);
    }

    @Transactional
    public Game deleteGame(Long id){
        Game game = findGame(id);
        repository.delete(game);
        return game;
    }
}
