package com.example.demo.services;

import com.example.demo.errors.NotFoundException;
import com.example.demo.models.Customer;
import com.example.demo.models.Game;
import com.example.demo.models.Play;
import com.example.demo.repositories.PlayRepository;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

@Service
public class PlayService {

    private final PlayRepository repository;
    private final GameService gameService;
    private final CustomerService customerService;

    public PlayService(PlayRepository repository, GameService gameService, CustomerService customerService){
        this.repository = repository;
        this.gameService = gameService;
        this.customerService = customerService;
    }

    @Transactional
    public Play addPlay(Long gameId, Date date, String description){
        Game game = gameService.findGame(gameId);

        Play play = new Play(game, date, description);
        return repository.save(play);
    }

    @Transactional
    public Play findPlay(Long id){
        return repository.findById(id).orElseThrow(
                () -> new NotFoundException(Play.class, id));
    }

    @Transactional
    public List<Play> getAllPlays(){
        return repository.findAll();
    }

    @Transactional
    public Play updatePlay(Long id, Date date, String description){
        Play play = findPlay(id);

        play.setDate(date);
        play.setDescription(description);

        return repository.save(play);
    }

    @Transactional
    public Play deletePlay(Long id){
        Play play = findPlay(id);
        repository.delete(play);
        return play;
    }

    @Transactional
    public boolean addCustomer(Long id, Long customerId){
        final Play play = findPlay(id);
        final Customer customer = customerService.findCustomer(customerId);

        if (customer.addPlay(play)){
            repository.save(play);
            return true;
        }
        return false;
    }
}
